==> distribution-6.0.0-dev.128.zip: drr/regulation/csa/rewrite/margin/validation/exists/CSAMarginReportOnlyExistsValidator.java <==
package drr.regulation.csa.rewrite.margin.validation.exists;

import cdm.base.staticdata.asset.common.ISOCurrencyCodeEnum;
import cdm.base.staticdata.party.PartyIdentifierTypeEnum;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.MarginActionEnum;
import drr.regulation.common.SupervisoryBodyEnum;
import drr.regulation.csa.rewrite.margin.CSAMarginReport;
import drr.standards.iso.CollateralisationType3Code__1;
import java.math.BigDecimal;
import java.time.ZonedDateTime;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class CSAMarginReportOnlyExistsValidator implements ValidatorWithArg<CSAMarginReport, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends CSAMarginReport> ValidationResult<CSAMarginReport> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("counterparty1", ExistenceChecker.isSet((String) o.getCounterparty1()))
				.put("counterparty2", ExistenceChecker.isSet((String) o.getCounterparty2()))
				.put("counterparty2IdentifierSource", ExistenceChecker.isSet((String) o.getCounterparty2IdentifierSource()))
				.put("reportingTimestamp", ExistenceChecker.isSet((ZonedDateTime) o.getReportingTimestamp()))
				.put("uniqueTransactionIdentifier", ExistenceChecker.isSet((String) o.getUniqueTransactionIdentifier()))
				.put("submitterIdentifier", ExistenceChecker.isSet((String) o.getSubmitterIdentifier()))
				.put("collateralisationCategory", ExistenceChecker.isSet((CollateralisationType3Code__1) o.getCollateralisationCategory()))
				.put("portfolioContainingNonReportableComponentIndicator", ExistenceChecker.isSet((Boolean) o.getPortfolioContainingNonReportableComponentIndicator()))
				.put("initialMarginPostedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginPostedByTheReportingCounterpartyPreHaircut()))
				.put("initialMarginPostedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginPostedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfInitialMarginPosted", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfInitialMarginPosted()))
				.put("initialMarginCollectedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginCollectedByTheReportingCounterpartyPreHaircut()))
				.put("initialMarginCollectedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginCollectedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfInitialMarginCollected", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfInitialMarginCollected()))
				.put("variationMarginPostedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginPostedByTheReportingCounterpartyPreHaircut()))
				.put("variationMarginPostedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginPostedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfVariationMarginPosted", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfVariationMarginPosted()))
				.put("variationMarginCollectedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginCollectedByTheReportingCounterpartyPreHaircut()))
				.put("variationMarginCollectedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginCollectedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfVariationMarginCollected", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfVariationMarginCollected()))
				.put("variationMarginCollateralPortfolioCode", ExistenceChecker.isSet((String) o.getVariationMarginCollateralPortfolioCode()))
				.put("initialMarginCollateralPortfolioCode", ExistenceChecker.isSet((String) o.getInitialMarginCollateralPortfolioCode()))
				.put("eventTimestamp", ExistenceChecker.isSet((ZonedDateTime) o.getEventTimestamp()))
				.put("actionType", ExistenceChecker.isSet((MarginActionEnum) o.getActionType()))
				.put("tradeParty1IDType", ExistenceChecker.isSet((PartyIdentifierTypeEnum) o.getTradeParty1IDType()))
				.put("submittingPartyIDType", ExistenceChecker.isSet((PartyIdentifierTypeEnum) o.getSubmittingPartyIDType()))
				.put("usiID", ExistenceChecker.isSet((String) o.getUsiID()))
				.put("usiIDPrefix", ExistenceChecker.isSet((String) o.getUsiIDPrefix()))
				.put("tradeParty1ReportingDestination", ExistenceChecker.isSet((List<SupervisoryBodyEnum>) o.getTradeParty1ReportingDestination()))
				.put("comment1", ExistenceChecker.isSet((String) o.getComment1()))
				.put("messageID", ExistenceChecker.isSet((String) o.getMessageID()))
				.put("messageType", ExistenceChecker.isSet((String) o.getMessageType()))
				.put("version", ExistenceChecker.isSet((String) o.getVersion()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("CSAMarginReport", ValidationType.ONLY_EXISTS, "CSAMarginReport", path, "");
		}
		return failure("CSAMarginReport", ValidationType.ONLY_EXISTS, "CSAMarginReport", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.17.1.zip: drr/regulation/csa/rewrite/margin/validation/exists/CSAMarginReportOnlyExistsValidator.java <==
package drr.regulation.csa.rewrite.margin.validation.exists;

import cdm.base.staticdata.asset.common.ISOCurrencyCodeEnum;
import cdm.base.staticdata.party.PartyIdentifierTypeEnum;
import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.regulation.common.MarginActionEnum;
import drr.regulation.common.SupervisoryBodyEnum;
import drr.regulation.csa.rewrite.margin.CSAMarginReport;
import drr.standards.iso.CollateralisationType3Code__1;
import java.math.BigDecimal;
import java.time.ZonedDateTime;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class CSAMarginReportOnlyExistsValidator implements ValidatorWithArg<CSAMarginReport, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends CSAMarginReport> ValidationResult<CSAMarginReport> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("counterparty1", ExistenceChecker.isSet((String) o.getCounterparty1()))
				.put("counterparty2", ExistenceChecker.isSet((String) o.getCounterparty2()))
				.put("counterparty2IdentifierSource", ExistenceChecker.isSet((String) o.getCounterparty2IdentifierSource()))
				.put("reportingTimestamp", ExistenceChecker.isSet((ZonedDateTime) o.getReportingTimestamp()))
				.put("uniqueTransactionIdentifier", ExistenceChecker.isSet((String) o.getUniqueTransactionIdentifier()))
				.put("submitterIdentifier", ExistenceChecker.isSet((String) o.getSubmitterIdentifier()))
				.put("collateralisationCategory", ExistenceChecker.isSet((CollateralisationType3Code__1) o.getCollateralisationCategory()))
				.put("portfolioContainingNonReportableComponentIndicator", ExistenceChecker.isSet((Boolean) o.getPortfolioContainingNonReportableComponentIndicator()))
				.put("initialMarginPostedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginPostedByTheReportingCounterpartyPreHaircut()))
				.put("initialMarginPostedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginPostedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfInitialMarginPosted", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfInitialMarginPosted()))
				.put("initialMarginCollectedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginCollectedByTheReportingCounterpartyPreHaircut()))
				.put("initialMarginCollectedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getInitialMarginCollectedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfInitialMarginCollected", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfInitialMarginCollected()))
				.put("variationMarginPostedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginPostedByTheReportingCounterpartyPreHaircut()))
				.put("variationMarginPostedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginPostedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfVariationMarginPosted", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfVariationMarginPosted()))
				.put("variationMarginCollectedByTheReportingCounterpartyPreHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginCollectedByTheReportingCounterpartyPreHaircut()))
				.put("variationMarginCollectedByTheReportingCounterpartyPostHaircut", ExistenceChecker.isSet((BigDecimal) o.getVariationMarginCollectedByTheReportingCounterpartyPostHaircut()))
				.put("currencyOfVariationMarginCollected", ExistenceChecker.isSet((ISOCurrencyCodeEnum) o.getCurrencyOfVariationMarginCollected()))
				.put("variationMarginCollateralPortfolioCode", ExistenceChecker.isSet((String) o.getVariationMarginCollateralPortfolioCode()))
				.put("initialMarginCollateralPortfolioCode", ExistenceChecker.isSet((String) o.getInitialMarginCollateralPortfolioCode()))
				.put("eventTimestamp", ExistenceChecker.isSet((ZonedDateTime) o.getEventTimestamp()))
				.put("actionType", ExistenceChecker.isSet((MarginActionEnum) o.getActionType()))
				.put("tradeParty1IDType", ExistenceChecker.isSet((PartyIdentifierTypeEnum) o.getTradeParty1IDType()))
				.put("submittingPartyIDType", ExistenceChecker.isSet((PartyIdentifierTypeEnum) o.getSubmittingPartyIDType()))
				.put("usiID", ExistenceChecker.isSet((String) o.getUsiID()))
				.put("usiIDPrefix", ExistenceChecker.isSet((String) o.getUsiIDPrefix()))
				.put("tradeParty1ReportingDestination", ExistenceChecker.isSet((List<SupervisoryBodyEnum>) o.getTradeParty1ReportingDestination()))
				.put("comment1", ExistenceChecker.isSet((String) o.getComment1()))
				.put("messageID", ExistenceChecker.isSet((String) o.getMessageID()))
				.put("messageType", ExistenceChecker.isSet((String) o.getMessageType()))
				.put("version", ExistenceChecker.isSet((String) o.getVersion()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("CSAMarginReport", ValidationResult.ValidationType.ONLY_EXISTS, "CSAMarginReport", path, "");
		}
		return failure("CSAMarginReport", ValidationResult.ValidationType.ONLY_EXISTS, "CSAMarginReport", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
